@@ -17,11 +17,12 @@ Camera transformation helper code.
 """
 
 import math
-from typing import List, Literal, Optional, Tuple
+from typing import List, Optional, Tuple
 
 import numpy as np
 import torch
 from torchtyping import TensorType
+from typing_extensions import Literal
 
 _EPS = np.finfo(float).eps * 4.0
 
@@ -406,20 +407,21 @@ def rotation_matrix(a: TensorType[3], b: TensorType[3]) -> TensorType[3, 3]:
     return torch.eye(3) + skew_sym_mat + skew_sym_mat @ skew_sym_mat * ((1 - c) / (s**2 + 1e-8))
 
 
-def auto_orient_poses(
-    poses: TensorType["num_poses":..., 4, 4], method: Literal["pca", "up"] = "up"
+def auto_orient_and_center_poses(
+    poses: TensorType["num_poses":..., 4, 4], method: Literal["pca", "up", "none"] = "up", center_poses: bool = True
 ) -> TensorType["num_poses":..., 3, 4]:
     """Orients and centers the poses. We provide two methods for orientation: pca and up.
 
     pca: Orient the poses so that the principal component of the points is aligned with the axes.
         This method works well when all of the cameras are in the same plane.
-
     up: Orient the poses so that the average up vector is aligned with the z axis.
         This method works well when images are not at arbitrary angles.
 
+
     Args:
         poses: The poses to orient.
-        method: The method to use for orientation. Either "pca" or "up".
+        method: The method to use for orientation.
+        center_poses: If True, the poses are centered around the origin.
 
     Returns:
         The oriented poses.
@@ -428,16 +430,21 @@ def auto_orient_poses(
     translation = poses[..., :3, 3]
 
     mean_translation = torch.mean(translation, dim=0)
-    translation = translation - mean_translation
+    translation_diff = translation - mean_translation
+
+    if center_poses:
+        translation = mean_translation
+    else:
+        translation = torch.zeros_like(mean_translation)
 
     if method == "pca":
-        _, eigvec = torch.linalg.eigh(translation.T @ translation)
+        _, eigvec = torch.linalg.eigh(translation_diff.T @ translation_diff)
         eigvec = torch.flip(eigvec, dims=(-1,))
 
         if torch.linalg.det(eigvec) < 0:
             eigvec[:, 2] = -eigvec[:, 2]
 
-        transform = torch.cat([eigvec, eigvec @ -mean_translation[..., None]], dim=-1)
+        transform = torch.cat([eigvec, eigvec @ -translation[..., None]], dim=-1)
         oriented_poses = transform @ poses
 
         if oriented_poses.mean(axis=0)[2, 1] < 0:
@@ -447,7 +454,10 @@ def auto_orient_poses(
         up = up / torch.linalg.norm(up)
 
         rotation = rotation_matrix(up, torch.Tensor([0, 0, 1]))
-        transform = torch.cat([rotation, rotation @ -mean_translation[..., None]], dim=-1)
+        transform = torch.cat([rotation, rotation @ -translation[..., None]], dim=-1)
         oriented_poses = transform @ poses
+    elif method == "none":
+        oriented_poses = poses
+        poses[:, 3, :3] -= translation
 
     return oriented_poses
